@@ -24,5 +24,7 @@ This module contains functions that manipulate geometry information:
  - load_crystfel_geometry()
 """
 
-from .geometry import compute_pix_maps, compute_visualization_pix_maps, apply_geometry_to_data
-from .crystfel_utils import load_crystfel_geometry
+from .crystfel_utils import (CrystFELGeometry, TypeBadRegion, TypeBeam,
+                             TypeDetector, TypePanel, load_crystfel_geometry)
+from .geometry import (apply_geometry_to_data, compute_pix_maps,
+                       compute_visualization_pix_maps)
