@@ -24,14 +24,17 @@ import copy
 import math
 import re
 import sys
-from typing import Dict, List, Tuple, Type, Union  # pylint: disable=unused-import
+from typing import Dict, List, NamedTuple, Tuple, Union
 
 from mypy_extensions import TypedDict
 
-
 TypeBeam = TypedDict(  # pylint: disable=invalid-name
     "TypeBeam",
-    {"photon_energy": float, "photon_energy_from": str, "photon_energy_scale": float,},
+    {
+        "photon_energy": float,
+        "photon_energy_from": str,
+        "photon_energy_scale": float,
+    },
     total=True,
 )
 
@@ -117,6 +120,14 @@ TypeDetector = TypedDict(  # pylint: disable=invalid-name
 )
 
 
+class CrystFELGeometry(NamedTuple):
+    """Collection of objects as returned by load_crystfel_geometry"""
+
+    detector: TypeDetector
+    beam: TypeBeam
+    hdf5_peak_path: Union[str, None]
+
+
 def _assplode_algebraic(value):
     # type: (str) -> List[str]
     # Re-implementation of assplode_algegraic from libcrystfel/src/detector.c.
@@ -462,9 +473,7 @@ def _find_min_max_d(detector):
         )
 
 
-def load_crystfel_geometry(
-    filename: str,
-) -> Tuple[TypeDetector, TypeBeam, Union[str, None]]:
+def load_crystfel_geometry(filename: str) -> CrystFELGeometry:
     """
     Loads a CrystFEL geometry file.
 
@@ -1005,8 +1014,10 @@ def load_crystfel_geometry(
         raise RuntimeError(
             "The following error occurred while reading the {0} geometry"
             "file {1}: {2}".format(
-                filename, exc_type.__name__, exc_value,  # type: ignore
+                filename,
+                exc_type.__name__,  # type: ignore
+                exc_value,  # type: ignore
             )
         ) from exc
 
-    return detector, beam, hdf5_peak_path
+    return CrystFELGeometry(detector=detector, beam=beam, hdf5_peak_path=hdf5_peak_path)
